@@ -1,6 +1,6 @@
 # Django
 from django.db.models.signals import post_save, post_delete
-from django.db.models import Manager
+from django.db.models import ManyToManyField
 from django.conf import settings
 
 # Project
@@ -19,10 +19,20 @@ def signal_delete_save(sender, instance, using, **kwargs):
 def send(routing_key):
     @staticmethod
     def wrapper(instances):
-        JobClient().call(
-            routing_key,
-            [getattr(i, 'serialized_data', i.__dict__) for i in instances]
-        )
+        response = []
+        for i in instances:
+            fields = i._meta.get_fields()
+            data = {}
+
+            for field in fields:
+                name = field.name
+                data[name] = getattr(i, name)
+
+                if field.__class__ is ManyToManyField:
+                    data[name] = list(data[name].values_list('id', flat=True))
+
+            response.append(data)
+        JobClient().call(routing_key, response)
 
     return wrapper
 
